# Changelog

<!--next-version-placeholder-->

## v0.2.1 (2022-12-07)
### Fix
* Added missing tests module ([`9d4581c`](https://github.com/awmath/django-bulk-signals/commit/9d4581cbd0bc5a6f6d212e1ca796a1349dad2f79))
* Bulk_update no longer triggers the pre_update signal ([`809c86a`](https://github.com/awmath/django-bulk-signals/commit/809c86adcbe92d485ca0c1c48b59792ec26efdd4))

## v0.2.0 (2022-12-07)
### Feature
* Added pre_*** action signals ([`ba6eb9a`](https://github.com/awmath/django-bulk-signals/commit/ba6eb9a869dd683d8675d6e45b41d67159ba0f13))

## v0.1.1 (2021-12-09)
### Fix
* **ci:** Wrong branch for semantic release ([`b9758b1`](https://github.com/awmath/django-bulk-signals/commit/b9758b13f5410d13fb844d7524dcaa0231b6be94))
* **ci:** Coverage exports xml for codecov ([`7841dd7`](https://github.com/awmath/django-bulk-signals/commit/7841dd7dc9ff3dedbf477c8da43e8fe2c00667fb))

### Documentation
* Added app install to README.md ([`8b1ac60`](https://github.com/awmath/django-bulk-signals/commit/8b1ac6003549f4f9c67d7055ec45cf9823b4ab4e))
